Changelog
=========


1.0 (2018-08-24)
----------------

- PEP8/PyFlakes

- Removed no longer needed utility from configure.zcml.

- Added more tests.

- Use the @implementer class decorator instead of implements.

- The implements API is deprecated, and will not work in Python3.

- Replace the pinyin with the python-slugify.


1.0.dev0 (2012-10-28)
----------------------

- Initial release
